//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[KokushiHandPattern](index.md)/[repeated](repeated.md)

# repeated

[common]\
open override val [repeated](repeated.md): [Tile](../../mahjongutils.models/-tile/index.md)?

重复的幺九牌
